@@ -52,8 +52,8 @@ static inline _Complex double * _pCd(doublecomplex *z) {return (_Complex double*
 #endif
 #define pCf(z) (*_pCf(z))
 #define pCd(z) (*_pCd(z))
-typedef int logical;
-typedef short int shortlogical;
+typedef blasint logical;
+
 typedef char logical1;
 typedef char integer1;
 
@@ -260,7 +260,7 @@ static char junk[] = "\n@(#)LIBF77 VERSION 19990503\n";
 
 /* procedure parameter types for -A and -C++ */
 
-#define F2C_proc_par_types 1
+
 #ifdef __cplusplus
 typedef logical (*L_fp)(...);
 #else
@@ -718,7 +718,7 @@ f"> */
 /* > \endverbatim */
 /* > */
 /*  ===================================================================== */
-/* Subroutine */ int ctpttf_(char *transr, char *uplo, integer *n, complex *
+/* Subroutine */ void ctpttf_(char *transr, char *uplo, integer *n, complex *
 	ap, complex *arf, integer *info)
 {
     /* System generated locals */
@@ -760,13 +760,13 @@ f"> */
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("CTPTTF", &i__1, (ftnlen)6);
-	return 0;
+	return;
     }
 
 /*     Quick return if possible */
 
     if (*n == 0) {
-	return 0;
+	return;
     }
 
     if (*n == 1) {
@@ -776,7 +776,7 @@ f"> */
 	    r_cnjg(&q__1, ap);
 	    arf[0].r = q__1.r, arf[0].i = q__1.i;
 	}
-	return 0;
+	return;
     }
 
 /*     Size of array ARF(0:NT-1) */
@@ -1112,7 +1112,7 @@ f"> */
 
     }
 
-    return 0;
+    return;
 
 /*     End of CTPTTF */
 
