@@ -52,8 +52,8 @@ static inline _Complex double * _pCd(doublecomplex *z) {return (_Complex double*
 #endif
 #define pCf(z) (*_pCf(z))
 #define pCd(z) (*_pCd(z))
-typedef int logical;
-typedef short int shortlogical;
+typedef blasint logical;
+
 typedef char logical1;
 typedef char integer1;
 
@@ -260,7 +260,7 @@ static char junk[] = "\n@(#)LIBF77 VERSION 19990503\n";
 
 /* procedure parameter types for -A and -C++ */
 
-#define F2C_proc_par_types 1
+
 #ifdef __cplusplus
 typedef logical (*L_fp)(...);
 #else
@@ -673,7 +673,7 @@ f"> */
 /* > \endverbatim */
 /* > */
 /*  ===================================================================== */
-/* Subroutine */ int dgebal_(char *job, integer *n, doublereal *a, integer *
+/* Subroutine */ void dgebal_(char *job, integer *n, doublereal *a, integer *
 	lda, integer *ilo, integer *ihi, doublereal *scale, integer *info)
 {
     /* System generated locals */
@@ -686,10 +686,10 @@ f"> */
     doublereal c__, f, g;
     integer i__, j, k, l, m;
     doublereal r__, s;
-    extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
+    extern /* Subroutine */ void dscal_(integer *, doublereal *, doublereal *, 
 	    integer *);
     extern logical lsame_(char *, char *);
-    extern /* Subroutine */ int dswap_(integer *, doublereal *, integer *, 
+    extern /* Subroutine */ void dswap_(integer *, doublereal *, integer *, 
 	    doublereal *, integer *);
     doublereal sfmin1, sfmin2, sfmax1, sfmax2, ca, ra;
     extern doublereal dlamch_(char *);
@@ -729,7 +729,7 @@ f"> */
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("DGEBAL", &i__1, (ftnlen)6);
-	return 0;
+	return;
     }
 
     k = 1;
@@ -894,7 +894,7 @@ L160:
 	    *info = -3;
 	    i__2 = -(*info);
 	    xerbla_("DGEBAL", &i__2, (ftnlen)6);
-	    return 0;
+	    return;
 	}
 	f *= 2.;
 	c__ *= 2.;
@@ -956,7 +956,7 @@ L210:
     *ilo = k;
     *ihi = l;
 
-    return 0;
+    return;
 
 /*     End of DGEBAL */
 
