@@ -52,8 +52,8 @@ static inline _Complex double * _pCd(doublecomplex *z) {return (_Complex double*
 #endif
 #define pCf(z) (*_pCf(z))
 #define pCd(z) (*_pCd(z))
-typedef int logical;
-typedef short int shortlogical;
+typedef blasint logical;
+
 typedef char logical1;
 typedef char integer1;
 
@@ -260,7 +260,7 @@ static char junk[] = "\n@(#)LIBF77 VERSION 19990503\n";
 
 /* procedure parameter types for -A and -C++ */
 
-#define F2C_proc_par_types 1
+
 #ifdef __cplusplus
 typedef logical (*L_fp)(...);
 #else
@@ -660,7 +660,7 @@ f"> */
 /* > \endverbatim */
 /* > */
 /*  ===================================================================== */
-/* Subroutine */ int dlasq4_(integer *i0, integer *n0, doublereal *z__, 
+/* Subroutine */ void dlasq4_(integer *i0, integer *n0, doublereal *z__, 
 	integer *pp, integer *n0in, doublereal *dmin__, doublereal *dmin1, 
 	doublereal *dmin2, doublereal *dn, doublereal *dn1, doublereal *dn2, 
 	doublereal *tau, integer *ttype, doublereal *g)
@@ -694,7 +694,7 @@ f"> */
     if (*dmin__ <= 0.) {
 	*tau = -(*dmin__);
 	*ttype = -1;
-	return 0;
+	return;
     }
 
     nn = (*n0 << 2) + *pp;
@@ -747,7 +747,7 @@ f"> */
 		    gam = *dn;
 		    a2 = 0.;
 		    if (z__[nn - 5] > z__[nn - 7]) {
-			return 0;
+			return;
 		    }
 		    b2 = z__[nn - 5] / z__[nn - 7];
 		    np = nn - 9;
@@ -755,11 +755,11 @@ f"> */
 		    np = nn - (*pp << 1);
 		    gam = *dn1;
 		    if (z__[np - 4] > z__[np - 2]) {
-			return 0;
+			return;
 		    }
 		    a2 = z__[np - 4] / z__[np - 2];
 		    if (z__[nn - 9] > z__[nn - 11]) {
-			return 0;
+			return;
 		    }
 		    b2 = z__[nn - 9] / z__[nn - 11];
 		    np = nn - 13;
@@ -775,7 +775,7 @@ f"> */
 		    }
 		    b1 = b2;
 		    if (z__[i4] > z__[i4 - 2]) {
-			return 0;
+			return;
 		    }
 		    b2 *= z__[i4] / z__[i4 - 2];
 		    a2 += b2;
@@ -807,7 +807,7 @@ L20:
 	    b2 = z__[np - 6];
 	    gam = *dn2;
 	    if (z__[np - 8] > b2 || z__[np - 4] > b1) {
-		return 0;
+		return;
 	    }
 	    a2 = z__[np - 8] / b2 * (z__[np - 4] / b1 + 1.);
 
@@ -823,7 +823,7 @@ L20:
 		    }
 		    b1 = b2;
 		    if (z__[i4] > z__[i4 - 2]) {
-			return 0;
+			return;
 		    }
 		    b2 *= z__[i4] / z__[i4 - 2];
 		    a2 += b2;
@@ -865,7 +865,7 @@ L40:
 	    *ttype = -7;
 	    s = *dmin1 * .333;
 	    if (z__[nn - 5] > z__[nn - 7]) {
-		return 0;
+		return;
 	    }
 	    b1 = z__[nn - 5] / z__[nn - 7];
 	    b2 = b1;
@@ -876,7 +876,7 @@ L40:
 	    for (i4 = (*n0 << 2) - 9 + *pp; i4 >= i__1; i4 += -4) {
 		a2 = b1;
 		if (z__[i4] > z__[i4 - 2]) {
-		    return 0;
+		    return;
 		}
 		b1 *= z__[i4] / z__[i4 - 2];
 		b2 += b1;
@@ -922,7 +922,7 @@ L60:
 	    *ttype = -10;
 	    s = *dmin2 * .333;
 	    if (z__[nn - 5] > z__[nn - 7]) {
-		return 0;
+		return;
 	    }
 	    b1 = z__[nn - 5] / z__[nn - 7];
 	    b2 = b1;
@@ -932,7 +932,7 @@ L60:
 	    i__1 = (*i0 << 2) - 1 + *pp;
 	    for (i4 = (*n0 << 2) - 9 + *pp; i4 >= i__1; i4 += -4) {
 		if (z__[i4] > z__[i4 - 2]) {
-		    return 0;
+		    return;
 		}
 		b1 *= z__[i4] / z__[i4 - 2];
 		b2 += b1;
@@ -970,7 +970,7 @@ L80:
     }
 
     *tau = s;
-    return 0;
+    return;
 
 /*     End of DLASQ4 */
 
