@@ -52,8 +52,8 @@ static inline _Complex double * _pCd(doublecomplex *z) {return (_Complex double*
 #endif
 #define pCf(z) (*_pCf(z))
 #define pCd(z) (*_pCd(z))
-typedef int logical;
-typedef short int shortlogical;
+typedef blasint logical;
+
 typedef char logical1;
 typedef char integer1;
 
@@ -260,7 +260,7 @@ static char junk[] = "\n@(#)LIBF77 VERSION 19990503\n";
 
 /* procedure parameter types for -A and -C++ */
 
-#define F2C_proc_par_types 1
+
 #ifdef __cplusplus
 typedef logical (*L_fp)(...);
 #else
@@ -683,7 +683,7 @@ static integer c_n1 = -1;
 /* > \endverbatim */
 
 /*  ===================================================================== */
-/* Subroutine */ int ssytri_3_(char *uplo, integer *n, real *a, integer *lda,
+/* Subroutine */ void ssytri_3_(char *uplo, integer *n, real *a, integer *lda,
 	 real *e, integer *ipiv, real *work, integer *lwork, integer *info)
 {
     /* System generated locals */
@@ -691,7 +691,7 @@ static integer c_n1 = -1;
 
     /* Local variables */
     extern logical lsame_(char *, char *);
-    extern /* Subroutine */ int ssytri_3x_(char *, integer *, real *, 
+    extern /* Subroutine */ void ssytri_3x_(char *, integer *, real *, 
 	    integer *, real *, integer *, real *, integer *, integer *);
     logical upper;
     integer nb;
@@ -747,16 +747,16 @@ static integer c_n1 = -1;
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("SSYTRI_3", &i__1, (ftnlen)8);
-	return 0;
+	return;
     } else if (lquery) {
 	work[1] = (real) lwkopt;
-	return 0;
+	return;
     }
 
 /*     Quick return if possible */
 
     if (*n == 0) {
-	return 0;
+	return;
     }
 
     ssytri_3x_(uplo, n, &a[a_offset], lda, &e[1], &ipiv[1], &work[1], &nb, 
@@ -764,7 +764,7 @@ static integer c_n1 = -1;
 
     work[1] = (real) lwkopt;
 
-    return 0;
+    return;
 
 /*     End of SSYTRI_3 */
 
